pub struct IfaceIter<'a, 'd> { /* private fields */ }Expand description
Iterator over the interfaces of a Stack, returned by Stack::ifaces.
Each item borrows the stack, so only one can exist at a time. That is why this is
not an Iterator and cannot be used in a for loop. Use while let:
let mut iter = stack.ifaces();
while let Some((handle, item)) = iter.next() {
let _ = (handle, item.hardware_addr());
}Implementations