xarxa

Crates

git

Versions

default

Flavors

MediumMismatch

Struct MediumMismatch 

pub struct MediumMismatch;
The interface’s medium can not do this.

Returned by Iface::set_hardware_addr when the address is of another medium’s kind, and by the methods that turn on an address autoconfiguration the medium does not support.